# 帮助或获取帮助

如果你喜欢`fastapi_amis_admin`项目,或者它对你有用,你可以通过以下方式帮助`fastapi_amis_admin`.

## GitHub 中的 Star

您可以在 GitHub 中"为 FastAPI 加注星标"（单击右上角的星形按钮）：

[https://github.com/amisadmin/fastapi_amis_admin](https://github.com/amisadmin/fastapi_amis_admin) ⭐️

通过添加星号，其他用户将能够更轻松地找到它，并看到它已经对其他人有用.

## 帮助其他人解决 GitHub 中的问题

您可以看到[存在的问题](https://github.com/amisadmin/fastapi_amis_admin/issues)并尝试帮助他人，大多数时候，这些问题您可能已经知道答案.🤓

## 创建问题

您可以在 GitHub 存储库中[创建新问题](https://github.com/amisadmin/fastapi_amis_admin/issues/new/choose)，例如：

- 提出**问题**或询问**问题**.
- 建议一个**新功能**.

**注意**：如果您创建了一个问题，那么我将要求您也帮助其他人.😉

## 加入群聊

目前仅建立了QQ群聊: [229036692](https://jq.qq.com/?_wv=1027&k=U4Dv6x8W),感兴趣的伙伴可以加入一起讨论.

## 创建拉取请求

您可以使用拉取请求为源代码[做出贡献]，例如：

- 修复您在文档中找到的拼写错误.
- 帮助[将文档翻译成]您的语言.
    - 您还可以帮助审阅其他人创建的翻译.
- 建议新的文档部分.
- 修复现有问题/错误.
- 添加新功能.

## 赞助作者

`fastapi-amis-admin`的开发与维护,包括文档编写都是非常耗时的工作,如果你想支持`fastapi-amis-admin`的开发,你可以通过以下方式在经济上支持作者.

- [爱发电 (afdian.net)](https://afdian.net/@amisadmin/plan)

- [PayPal.Me](https://www.paypal.com/paypalme/amisadmin)

## 赞助为项目提供支持的工具

FastAPI-Amis-Admin非常感谢以下项目的支持.

您还可以赞助：

- [Fastapi](https://fastapi.tiangolo.com/)
- [Amis](https://baidu.gitee.io/amis)
- [SQLModel](https://sqlmodel.tiangolo.com/)
- [Pydantic](https://pydantic-docs.helpmanual.io/)

